==> qt-creator-2.7.1-src.zip: qt-creator-2.7.1-src/src/plugins/madde/maemoqemumanager.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QEMURUNTIMEMANAGER_H
#define QEMURUNTIMEMANAGER_H

#include "maemoconstants.h"
#include "maemoqemuruntime.h"

#include <QMap>
#include <QObject>
#include <QProcess>

#include <QIcon>

QT_FORWARD_DECLARE_CLASS(QAction)
QT_FORWARD_DECLARE_CLASS(QStringList)

namespace ProjectExplorer {
class BuildConfiguration;
class Project;
class RunConfiguration;
class Target;
}

namespace QtSupport { class BaseQtVersion; }
namespace RemoteLinux { class RemoteLinuxRunConfiguration; }
namespace Utils { class FileSystemWatcher; }

namespace Madde {
namespace Internal {

class MaemoQemuManager : public QObject
{
    Q_OBJECT

public:
    static MaemoQemuManager& instance(QObject *parent = 0);

    bool runtimeForQtVersion(int uniqueId, MaemoQemuRuntime *rt) const;
    bool qemuIsRunning() const;
    Q_SLOT void startRuntime();

signals:
    void qemuProcessStatus(QemuStatus, const QString &error = QString());

private slots:
    void qtVersionsChanged(const QList<int> &addedIds, const QList<int> &removedIds, const QList<int> &changed);

    void projectAdded(ProjectExplorer::Project *project);
    void projectRemoved(ProjectExplorer::Project *project);
    void projectChanged(ProjectExplorer::Project *project);

    void targetAdded(ProjectExplorer::Target *target);
    void targetRemoved(ProjectExplorer::Target *target);
    void targetChanged(ProjectExplorer::Target *target);
    void systemChanged();

    void environmentChanged();  // needed to check for Qt version
    void deviceConfigurationChanged(ProjectExplorer::Target *target);

    void terminateRuntime();

    void qemuProcessFinished();
    void qemuProcessError(QProcess::ProcessError error);
    void qemuStatusChanged(QemuStatus status, const QString &error);
    void qemuOutput();

    void runtimeRootChanged(const QString &directory);
    void runtimeFolderChanged(const QString &directory);

private:
    MaemoQemuManager(QObject *parent);
    ~MaemoQemuManager();

    bool sessionHasMaemoTarget() const;

    void updateStarterIcon(bool running);
    void toggleStarterButton(ProjectExplorer::Target *target);
    bool targetUsesMatchingRuntimeConfig(ProjectExplorer::Target *target,
        QtSupport::BaseQtVersion **qtVersion = 0);

    void notify(const QList<int> uniqueIds);
    void showOrHideQemuButton();

private:
    QAction *m_qemuAction;
    QProcess *m_qemuProcess;
    Utils::FileSystemWatcher *runtimeRootWatcher();
    Utils::FileSystemWatcher *runtimeFolderWatcher();

    int m_runningQtId;
    bool m_userTerminated;
    QIcon m_qemuStarterIcon;
    QMap<int, MaemoQemuRuntime> m_runtimes;
    static MaemoQemuManager *m_instance;
    Utils::FileSystemWatcher *m_runtimeRootWatcher;
    Utils::FileSystemWatcher *m_runtimeFolderWatcher;
};

}   // namespace Internal
}   // namespace Madde

#endif  // QEMURUNTIMEMANAGER_H

==> qt-creator-2.8.0-src.zip: qt-creator-2.8.0-src/src/plugins/madde/maemoqemumanager.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MAEMOQEMUMANAGER_H
#define MAEMOQEMUMANAGER_H

#include "maemoconstants.h"
#include "maemoqemuruntime.h"

#include <QMap>
#include <QObject>
#include <QProcess>

#include <QIcon>

QT_FORWARD_DECLARE_CLASS(QAction)
QT_FORWARD_DECLARE_CLASS(QStringList)

namespace ProjectExplorer {
class BuildConfiguration;
class Project;
class RunConfiguration;
class Target;
}

namespace QtSupport { class BaseQtVersion; }
namespace RemoteLinux { class RemoteLinuxRunConfiguration; }
namespace Utils { class FileSystemWatcher; }

namespace Madde {
namespace Internal {

class MaemoQemuManager : public QObject
{
    Q_OBJECT

public:
    static MaemoQemuManager& instance(QObject *parent = 0);

    bool runtimeForQtVersion(int uniqueId, MaemoQemuRuntime *rt) const;
    bool qemuIsRunning() const;
    Q_SLOT void startRuntime();

signals:
    void qemuProcessStatus(QemuStatus, const QString &error = QString());

private slots:
    void qtVersionsChanged(const QList<int> &addedIds, const QList<int> &removedIds, const QList<int> &changed);

    void projectAdded(ProjectExplorer::Project *project);
    void projectRemoved(ProjectExplorer::Project *project);
    void projectChanged(ProjectExplorer::Project *project);

    void targetAdded(ProjectExplorer::Target *target);
    void targetRemoved(ProjectExplorer::Target *target);
    void targetChanged(ProjectExplorer::Target *target);
    void systemChanged();

    void environmentChanged();  // needed to check for Qt version
    void deviceConfigurationChanged(ProjectExplorer::Target *target);

    void terminateRuntime();

    void qemuProcessFinished();
    void qemuProcessError(QProcess::ProcessError error);
    void qemuStatusChanged(QemuStatus status, const QString &error);
    void qemuOutput();

    void runtimeRootChanged(const QString &directory);
    void runtimeFolderChanged(const QString &directory);

private:
    MaemoQemuManager(QObject *parent);
    ~MaemoQemuManager();

    bool sessionHasMaemoTarget() const;

    void updateStarterIcon(bool running);
    void toggleStarterButton(ProjectExplorer::Target *target);
    bool targetUsesMatchingRuntimeConfig(ProjectExplorer::Target *target,
        QtSupport::BaseQtVersion **qtVersion = 0);

    void notify(const QList<int> uniqueIds);
    void showOrHideQemuButton();

private:
    QAction *m_qemuAction;
    QProcess *m_qemuProcess;
    Utils::FileSystemWatcher *runtimeRootWatcher();
    Utils::FileSystemWatcher *runtimeFolderWatcher();

    int m_runningQtId;
    bool m_userTerminated;
    QIcon m_qemuStarterIcon;
    QMap<int, MaemoQemuRuntime> m_runtimes;
    static MaemoQemuManager *m_instance;
    Utils::FileSystemWatcher *m_runtimeRootWatcher;
    Utils::FileSystemWatcher *m_runtimeFolderWatcher;
};

}   // namespace Internal
}   // namespace Madde

#endif  // MAEMOQEMUMANAGER_H
